# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-06-19 14:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ping_me', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='domain',
            name='id',
            field=models.AutoField(auto_created=True, default=1, primary_key=True, serialize=False, verbose_name='ID'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='domain',
            name='url',
            field=models.CharField(max_length=255, verbose_name='Adresse'),
        ),
    ]



# Generated by Django 2.0.6 on 2018-06-20 01:06

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ping_me', '0005_auto_20180620_0000'),
    ]

    operations = [
        migrations.CreateModel(
            name='PingSummary',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateField()),
                ('nb_success', models.IntegerField(default=0)),
                ('nb_errors', models.IntegerField(default=0)),
                ('domain', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ping_me.Domain')),
            ],
        ),
    ]



# Generated by Django 2.0.6 on 2018-06-19 23:56

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ping_me', '0003_auto_20180619_1711'),
    ]

    operations = [
        migrations.CreateModel(
            name='Ping',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateTimeField()),
                ('success', models.BooleanField()),
                ('address', models.GenericIPAddressField()),
                ('domain', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ping_me.Domain')),
            ],
        ),
    ]



# Generated by Django 2.0.6 on 2018-06-20 00:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ping_me', '0004_ping'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ping',
            name='date',
            field=models.DateTimeField(auto_now_add=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-06-19 17:11
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ping_me', '0002_auto_20180619_1423'),
    ]

    operations = [
        migrations.AlterField(
            model_name='domain',
            name='description',
            field=models.CharField(max_length=255, verbose_name='Description'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-06-19 13:08
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Domain',
            fields=[
                ('url', models.CharField(max_length=255, primary_key=True, serialize=False, verbose_name='Adresse')),
                ('description', models.TextField(verbose_name='Description')),
            ],
        ),
    ]
